==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/summary/ui/common/summary-table-filter/summary-table-filter.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { SummaryTableFilter } from './summary-table-filter.component';
import { SummaryTableFilterModule } from './summary-table-filter.module';
import { NoopAnimationsModule } from '@angular/platform-browser/animations';

describe('SummaryTableFilter', () => {
    let component: SummaryTableFilter;
    let fixture: ComponentFixture<SummaryTableFilter>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            declarations: [SummaryTableFilter],
            imports: [SummaryTableFilterModule, NoopAnimationsModule]
        });
        fixture = TestBed.createComponent(SummaryTableFilter);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/summary/ui/common/summary-table-filter/summary-table-filter.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { SummaryTableFilter } from './summary-table-filter.component';
import { NoopAnimationsModule } from '@angular/platform-browser/animations';

describe('SummaryTableFilter', () => {
    let component: SummaryTableFilter;
    let fixture: ComponentFixture<SummaryTableFilter>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            imports: [SummaryTableFilter, NoopAnimationsModule]
        });
        fixture = TestBed.createComponent(SummaryTableFilter);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});
